



if not exist %LIBRARY_INC%\\pano13\\version.h exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %LIBRARY_BIN%\\pano13.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
PTinfo -h
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %LIBRARY_BIN%\\panoinfo.exe exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
exit /B 0
